Welcome to Django Flag App's documentation!
===========================================

.. toctree::
   :maxdepth: 2
   :caption: Contents:

   introduction
   webAPI
   settings
   style-customisation
   contributing
   changelog



Indices and tables
==================

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`
